==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The specified key for the JSON. Must be between 1 and 100 characters in length.
 * @property value The specified value for the JSON. Must be between 1 and 100 characters in length.
 */
public data class VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs(
    public val key: Output<String>,
    public val `value`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs].
 */
@PulumiTagMarker
public class VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The specified key for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("yuuwuhqeaawlxaxr")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The specified value for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("eyupjfipiipmnsnt")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The specified key for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("qovxjqjfpwimioit")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The specified value for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("epqefmulcjucxemj")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs =
        VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The specified key for the JSON. Must be between 1 and 100 characters in length.
 * @property value The specified value for the JSON. Must be between 1 and 100 characters in length.
 */
public data class VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs(
    public val key: Output<String>,
    public val `value`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs].
 */
@PulumiTagMarker
public class VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The specified key for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("iyocjihraodhijrb")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The specified value for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("plnjuufdmrgyburr")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The specified key for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("lsharhhbklswrxfi")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The specified value for the JSON. Must be between 1 and 100 characters in length.
     */
    @JvmName("vyyfxidhkoijkgpd")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs =
        VirtualGatewaySpecLoggingAccessLogFileFormatJsonArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
